mate-rest-client
===========

This library provides a client for MATE's REST API.

## Acknowledgements

This material is based upon work supported by the United States Air Force and
Defense Advanced Research Project Agency (DARPA) under
Contract No. FA8750-19-C-0004. Any opinions, findings and conclusions or
recommendations expressed in this material are those of the author(s) and do
not necessarily reflect the views of the United States Air Force or DARPA.
Approved for Public Release, Distribution Unlimited.
